function [YPred, acc, Margin] = pred_itr(y,K,model,lambda,gamma,mbr)
%function [YPred, acc, Margin] = pred_itr(y,K,model,lambda,gamma,mbr)
%Predicts labels of new examples given the learnt model and the gram matrices
%Input:
% y - Labels of test examples
% K - K(:,:,k) is the kth gram matrix of test and training examples K(test,train,k)
% mbr - mbr(i)=j if i^th kernel belongs to j^th descriptor
% model, lambda, gamma - Model learnt using train_itr.m
%Output:
% YPred - Predicted labels of the test examples
% Margin - Margin of the test examples
% acc - testset accuracy
%
% Author : Saketha Nath.J - saketh@cse.iitb.ac.in

%    Copyright (C) 2009 Saketha Nath. J
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

[M,m,sn] = size(K);
K_new=zeros(M,m);

for i=1:sn
    K_new = K_new + lambda(i)*K(:,:,i)/gamma(mbr(i));
end
[YPred,acc,Margin] = svmpredict(y,[(1:M)' K_new],model);
acc=acc(1);

return
